==> piwigo-2.1.6.zip: piwigo/plugins/admin_multi_view/main.inc.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based picture gallery                                  |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2010 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 Piwigo team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+

/*
Plugin Name: Multi view
Version: 2.1.b
Description: Allows administrators to view gallery as guests and/or change the language and/or theme on the fly. Practical to debug changes...
Plugin URI: http://piwigo.org/ext/extension_view.php?eid=286
Author: Piwigo team
Author URI: http://piwigo.org
*/

add_event_handler('user_init', 'multiview_user_init' );

function multiview_user_init()
{
  if (!is_admin())
    return;
  include_once( dirname(__FILE__).'/is_admin.inc.php' );
}

?>

==> piwigo-2.5.1.zip: piwigo/plugins/admin_multi_view/main.inc.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2013 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 Piwigo team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+

/*
Plugin Name: Multi view
Version: 2.5.1
Description: Allows administrators to view gallery as guests and/or change the language and/or theme on the fly. Practical to debug changes...
Plugin URI: http://piwigo.org/ext/extension_view.php?eid=286
Author: Piwigo team
Author URI: http://piwigo.org
*/

add_event_handler('user_init', 'multiview_user_init' );
add_event_handler('init', 'multiview_init' );

function multiview_user_init()
{
  if (!is_admin())
    return;
  include_once( dirname(__FILE__).'/is_admin.inc.php' );
}

function multiview_init()
{
  if (!is_admin())
    return;
  include_once( dirname(__FILE__).'/is_admin_template.inc.php' );
}

?>
